pub struct Relation<T: Component> { /* private fields */ }Expand description
Represents a relationship between entities with associated metadata (payload).
Implementations
Sourceimpl<T: Component> Relation<T>
impl<T: Component> Relation<T>
Sourcepub fn install_to_registry(registry: &mut Registry)
pub fn install_to_registry(registry: &mut Registry)
Installs the relation type into the provided registry for entity processing.
Sourcepub fn register_to_processor(processor: &mut WorldProcessor)
pub fn register_to_processor(processor: &mut WorldProcessor)
Registers relation-specific entity remapping and inspection logic with the processor.
Sourcepub fn register_to_processor_debug(processor: &mut WorldProcessor)where
T: Debug,
pub fn register_to_processor_debug(processor: &mut WorldProcessor)where
T: Debug,
Registers debug-specific formatting for this relation in the processor.
Sourcepub fn new(payload: T, entity: Entity) -> Self
pub fn new(payload: T, entity: Entity) -> Self
Creates a new relation with a single connection.
Sourcepub fn with(self, payload: T, entity: Entity) -> Self
pub fn with(self, payload: T, entity: Entity) -> Self
Adds a connection to the relation and returns the modified relation.
Sourcepub fn add(&mut self, payload: T, entity: Entity)
pub fn add(&mut self, payload: T, entity: Entity)
Adds a connection to the relation, updating or inserting as necessary.
Sourcepub fn has(&self, entity: Entity) -> bool
pub fn has(&self, entity: Entity) -> bool
Checks if the relation has a connection with the given entity.
Sourcepub fn payload(&self, entity: Entity) -> Option<&T>
pub fn payload(&self, entity: Entity) -> Option<&T>
Gets the payload associated with the given entity.
Sourcepub fn payload_mut(&mut self, entity: Entity) -> Option<&mut T>
pub fn payload_mut(&mut self, entity: Entity) -> Option<&mut T>
Gets a mutable reference to the payload associated with the given entity.
Sourcepub fn entities(&self) -> impl Iterator<Item = Entity> + '_
pub fn entities(&self) -> impl Iterator<Item = Entity> + '_
Returns an iterator over all entities in the relation.